"use client";
import { ProductSkeleton } from "@/components/common/loading-skeleton/product-skeleton";
import { useCart } from "@/servers/data/use-cart";
import { useTranslations } from "next-intl";
import ProductsInBasket from "./sub-components/products-in-basket";
import PurchaseInvoice from "./sub-components/purchase-invoice";


function Cart() {
	const t = useTranslations("Cart");
	const { cart, isLoading, refetch } = useCart();

	console.log("cart: ", cart);

	return (
		<div className="flex flex-col-reverse items-start justify-between gap-3 md:gap-9 lg:flex-row lg:gap-10 xl:gap-20">
			<div className="container mx-auto p-4 md:p-8 font-sans" dir="rtl">
				<h1 className="mb-2 text-xl leading-7 text-custom-primary-accent md:mb-4 md:text-[32px] md:leading-[76px]">{t("ProductsInBasket")}</h1>

				{
					isLoading ? (
						<div className="mt-5">
							{Array.from({ length: 3 })?.map((_, index) => (
								<ProductSkeleton key={index} />
							))}
						</div>
					) : (
						cart?.data?.length > 0 ?
							<div className="flex flex-col-reverse items-start justify-between gap-3 md:gap-9 lg:flex-row lg:gap-10 xl:gap-20">

								<ProductsInBasket products={cart?.data} refetch={refetch} />
								<PurchaseInvoice invoice={cart} />
							</div>
							:
							<div className="flex flex-col items-center justify-center h-full">
								<h1 className="text-2xl font-bold">لا يوجد منتجات في السلة</h1>
							</div>
					)
				}
			</div>
		</div>
	);
}

export default Cart;

